/****************************************************************************
** Meta object code from reading C++ file 'vacationcheckjob.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libksieve-26.08.0/src/ksievecore/vacation/vacationcheckjob.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'vacationcheckjob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10KSieveCore16VacationCheckJobE_t {};
} // unnamed namespace

template <> constexpr inline auto KSieveCore::VacationCheckJob::qt_create_metaobjectdata<qt_meta_tag_ZN10KSieveCore16VacationCheckJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSieveCore::VacationCheckJob",
        "vacationScriptActive",
        "",
        "KSieveCore::VacationCheckJob*",
        "job",
        "sscriptName",
        "active",
        "error",
        "errorStr",
        "slotGetResult",
        "KManageSieve::SieveJob*",
        "success",
        "script",
        "slotGotActiveScripts",
        "KSieveCore::ParseUserScriptJob*",
        "slotGotList",
        "availableScripts",
        "activeScript",
        "emitError",
        "errorMessage",
        "searchVacationScript",
        "getNextScript"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'vacationScriptActive'
        QtMocHelpers::SignalData<void(KSieveCore::VacationCheckJob *, const QString &, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'slotGetResult'
        QtMocHelpers::SlotData<void(KManageSieve::SieveJob *, bool, const QString &, bool)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 4 }, { QMetaType::Bool, 11 }, { QMetaType::QString, 12 }, { QMetaType::Bool, 6 },
        }}),
        // Slot 'slotGotActiveScripts'
        QtMocHelpers::SlotData<void(KSieveCore::ParseUserScriptJob *)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 4 },
        }}),
        // Slot 'slotGotList'
        QtMocHelpers::SlotData<void(KManageSieve::SieveJob *, bool, const QStringList &, const QString &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 4 }, { QMetaType::Bool, 11 }, { QMetaType::QStringList, 16 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'emitError'
        QtMocHelpers::SlotData<void(const QString &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'searchVacationScript'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'getNextScript'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<VacationCheckJob, qt_meta_tag_ZN10KSieveCore16VacationCheckJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KSieveCore::VacationCheckJob::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KSieveCore16VacationCheckJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KSieveCore16VacationCheckJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10KSieveCore16VacationCheckJobE_t>.metaTypes,
    nullptr
} };

void KSieveCore::VacationCheckJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VacationCheckJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->vacationScriptActive((*reinterpret_cast<std::add_pointer_t<KSieveCore::VacationCheckJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 1: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->slotGetResult((*reinterpret_cast<std::add_pointer_t<KManageSieve::SieveJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 3: _t->slotGotActiveScripts((*reinterpret_cast<std::add_pointer_t<KSieveCore::ParseUserScriptJob*>>(_a[1]))); break;
        case 4: _t->slotGotList((*reinterpret_cast<std::add_pointer_t<KManageSieve::SieveJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 5: _t->emitError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->searchVacationScript(); break;
        case 7: _t->getNextScript(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KSieveCore::VacationCheckJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (VacationCheckJob::*)(KSieveCore::VacationCheckJob * , const QString & , bool )>(_a, &VacationCheckJob::vacationScriptActive, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (VacationCheckJob::*)(const QString & )>(_a, &VacationCheckJob::error, 1))
            return;
    }
}

const QMetaObject *KSieveCore::VacationCheckJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSieveCore::VacationCheckJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KSieveCore16VacationCheckJobE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KSieveCore::VacationCheckJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void KSieveCore::VacationCheckJob::vacationScriptActive(KSieveCore::VacationCheckJob * _t1, const QString & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void KSieveCore::VacationCheckJob::error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
