/****************************************************************************
** Meta object code from reading C++ file 'managesievewidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libksieve-26.08.0/src/ksieveui/widgets/managesievewidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'managesievewidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KSieveUi17ManageSieveWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto KSieveUi::ManageSieveWidget::qt_create_metaobjectdata<qt_meta_tag_ZN8KSieveUi17ManageSieveWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSieveUi::ManageSieveWidget",
        "updateButtons",
        "",
        "QTreeWidgetItem*",
        "item",
        "newScript",
        "KSieveUi::ManageSieveWidget::ScriptInfo",
        "info",
        "editScript",
        "scriptDeleted",
        "QUrl",
        "u",
        "serverSieveFound",
        "imapFound",
        "scriptRenamed",
        "oldUrl",
        "newUrl",
        "updateSieveSettingsDone",
        "slotItemChanged",
        "col",
        "slotContextMenuRequested",
        "QPoint",
        "p",
        "slotUpdateButtons",
        "slotDoubleClicked",
        "slotSystemNetworkOnlineStateChanged",
        "state",
        "slotCheckNetworkStatus",
        "setActiveScripts",
        "KSieveCore::ParseUserScriptJob*",
        "job",
        "slotCancelFetch",
        "slotRenameResult",
        "KManageSieve::SieveJob*",
        "success",
        "slotRenameFinished",
        "errorStr",
        "slotRenameScript",
        "slotGotList",
        "listScript",
        "activeScript",
        "slotNewScript",
        "slotEditScript",
        "slotDeleteScript",
        "slotDeactivateScript",
        "slotDeleteResult",
        "slotRefresh"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'updateButtons'
        QtMocHelpers::SignalData<void(QTreeWidgetItem *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'newScript'
        QtMocHelpers::SignalData<void(const KSieveUi::ManageSieveWidget::ScriptInfo &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'editScript'
        QtMocHelpers::SignalData<void(const KSieveUi::ManageSieveWidget::ScriptInfo &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'scriptDeleted'
        QtMocHelpers::SignalData<void(const QUrl &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'serverSieveFound'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'scriptRenamed'
        QtMocHelpers::SignalData<void(const QUrl &, const QUrl &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 15 }, { 0x80000000 | 10, 16 },
        }}),
        // Signal 'updateSieveSettingsDone'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotItemChanged'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *, int)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 19 },
        }}),
        // Slot 'slotContextMenuRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'slotUpdateButtons'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDoubleClicked'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotSystemNetworkOnlineStateChanged'
        QtMocHelpers::SlotData<void(bool)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'slotCheckNetworkStatus'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setActiveScripts'
        QtMocHelpers::SlotData<void(KSieveCore::ParseUserScriptJob *)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'slotCancelFetch'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRenameResult'
        QtMocHelpers::SlotData<void(KManageSieve::SieveJob *, bool)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 30 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'slotRenameFinished'
        QtMocHelpers::SlotData<void(const QUrl &, const QUrl &, const QString &, bool)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 15 }, { 0x80000000 | 10, 16 }, { QMetaType::QString, 36 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'slotRenameScript'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotGotList'
        QtMocHelpers::SlotData<void(KManageSieve::SieveJob *, bool, const QStringList &, const QString &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 30 }, { QMetaType::Bool, 34 }, { QMetaType::QStringList, 39 }, { QMetaType::QString, 40 },
        }}),
        // Slot 'slotNewScript'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEditScript'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDeleteScript'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDeactivateScript'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDeleteResult'
        QtMocHelpers::SlotData<void(KManageSieve::SieveJob *, bool)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 30 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'slotRefresh'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ManageSieveWidget, qt_meta_tag_ZN8KSieveUi17ManageSieveWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KSieveUi::ManageSieveWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KSieveUi17ManageSieveWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KSieveUi17ManageSieveWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KSieveUi17ManageSieveWidgetE_t>.metaTypes,
    nullptr
} };

void KSieveUi::ManageSieveWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ManageSieveWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updateButtons((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1]))); break;
        case 1: _t->newScript((*reinterpret_cast<std::add_pointer_t<KSieveUi::ManageSieveWidget::ScriptInfo>>(_a[1]))); break;
        case 2: _t->editScript((*reinterpret_cast<std::add_pointer_t<KSieveUi::ManageSieveWidget::ScriptInfo>>(_a[1]))); break;
        case 3: _t->scriptDeleted((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 4: _t->serverSieveFound((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->scriptRenamed((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 6: _t->updateSieveSettingsDone(); break;
        case 7: _t->slotItemChanged((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 8: _t->slotContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 9: _t->slotUpdateButtons(); break;
        case 10: _t->slotDoubleClicked((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1]))); break;
        case 11: _t->slotSystemNetworkOnlineStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->slotCheckNetworkStatus(); break;
        case 13: _t->setActiveScripts((*reinterpret_cast<std::add_pointer_t<KSieveCore::ParseUserScriptJob*>>(_a[1]))); break;
        case 14: _t->slotCancelFetch(); break;
        case 15: _t->slotRenameResult((*reinterpret_cast<std::add_pointer_t<KManageSieve::SieveJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 16: _t->slotRenameFinished((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 17: _t->slotRenameScript(); break;
        case 18: _t->slotGotList((*reinterpret_cast<std::add_pointer_t<KManageSieve::SieveJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 19: _t->slotNewScript(); break;
        case 20: _t->slotEditScript(); break;
        case 21: _t->slotDeleteScript(); break;
        case 22: _t->slotDeactivateScript(); break;
        case 23: _t->slotDeleteResult((*reinterpret_cast<std::add_pointer_t<KManageSieve::SieveJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 24: _t->slotRefresh(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ManageSieveWidget::*)(QTreeWidgetItem * )>(_a, &ManageSieveWidget::updateButtons, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageSieveWidget::*)(const KSieveUi::ManageSieveWidget::ScriptInfo & )>(_a, &ManageSieveWidget::newScript, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageSieveWidget::*)(const KSieveUi::ManageSieveWidget::ScriptInfo & )>(_a, &ManageSieveWidget::editScript, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageSieveWidget::*)(const QUrl & )>(_a, &ManageSieveWidget::scriptDeleted, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageSieveWidget::*)(bool )>(_a, &ManageSieveWidget::serverSieveFound, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageSieveWidget::*)(const QUrl & , const QUrl & )>(_a, &ManageSieveWidget::scriptRenamed, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageSieveWidget::*)()>(_a, &ManageSieveWidget::updateSieveSettingsDone, 6))
            return;
    }
}

const QMetaObject *KSieveUi::ManageSieveWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSieveUi::ManageSieveWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KSieveUi17ManageSieveWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KSieveUi::ManageSieveWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void KSieveUi::ManageSieveWidget::updateButtons(QTreeWidgetItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KSieveUi::ManageSieveWidget::newScript(const KSieveUi::ManageSieveWidget::ScriptInfo & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KSieveUi::ManageSieveWidget::editScript(const KSieveUi::ManageSieveWidget::ScriptInfo & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KSieveUi::ManageSieveWidget::scriptDeleted(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KSieveUi::ManageSieveWidget::serverSieveFound(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KSieveUi::ManageSieveWidget::scriptRenamed(const QUrl & _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void KSieveUi::ManageSieveWidget::updateSieveSettingsDone()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
