/****************************************************************************
** Meta object code from reading C++ file 'sieveeditormenubar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libksieve-26.08.0/src/ksieveui/editor/sieveeditormenubar.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sieveeditormenubar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KSieveUi18SieveEditorMenuBarE_t {};
} // unnamed namespace

template <> constexpr inline auto KSieveUi::SieveEditorMenuBar::qt_create_metaobjectdata<qt_meta_tag_ZN8KSieveUi18SieveEditorMenuBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSieveUi::SieveEditorMenuBar",
        "gotoLine",
        "",
        "find",
        "replace",
        "undo",
        "redo",
        "copy",
        "paste",
        "cut",
        "selectAll",
        "comment",
        "uncomment",
        "zoomIn",
        "zoomOut",
        "debugSieveScript",
        "zoomReset",
        "wordWrap",
        "state",
        "print",
        "printPreview",
        "setEditorMode",
        "editorMode",
        "slotUndoAvailable",
        "b",
        "slotRedoAvailable",
        "slotCopyAvailable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'gotoLine'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'find'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'replace'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'undo'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'redo'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'copy'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paste'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cut'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectAll'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'comment'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'uncomment'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'zoomIn'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'zoomOut'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'debugSieveScript'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'zoomReset'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wordWrap'
        QtMocHelpers::SignalData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Signal 'print'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'printPreview'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setEditorMode'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'slotUndoAvailable'
        QtMocHelpers::SlotData<void(bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'slotRedoAvailable'
        QtMocHelpers::SlotData<void(bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'slotCopyAvailable'
        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SieveEditorMenuBar, qt_meta_tag_ZN8KSieveUi18SieveEditorMenuBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KSieveUi::SieveEditorMenuBar::staticMetaObject = { {
    QMetaObject::SuperData::link<QMenuBar::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KSieveUi18SieveEditorMenuBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KSieveUi18SieveEditorMenuBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KSieveUi18SieveEditorMenuBarE_t>.metaTypes,
    nullptr
} };

void KSieveUi::SieveEditorMenuBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SieveEditorMenuBar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->gotoLine(); break;
        case 1: _t->find(); break;
        case 2: _t->replace(); break;
        case 3: _t->undo(); break;
        case 4: _t->redo(); break;
        case 5: _t->copy(); break;
        case 6: _t->paste(); break;
        case 7: _t->cut(); break;
        case 8: _t->selectAll(); break;
        case 9: _t->comment(); break;
        case 10: _t->uncomment(); break;
        case 11: _t->zoomIn(); break;
        case 12: _t->zoomOut(); break;
        case 13: _t->debugSieveScript(); break;
        case 14: _t->zoomReset(); break;
        case 15: _t->wordWrap((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->print(); break;
        case 17: _t->printPreview(); break;
        case 18: _t->setEditorMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->slotUndoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->slotRedoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->slotCopyAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMenuBar::*)()>(_a, &SieveEditorMenuBar::gotoLine, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMenuBar::*)()>(_a, &SieveEditorMenuBar::find, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMenuBar::*)()>(_a, &SieveEditorMenuBar::replace, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMenuBar::*)()>(_a, &SieveEditorMenuBar::undo, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMenuBar::*)()>(_a, &SieveEditorMenuBar::redo, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMenuBar::*)()>(_a, &SieveEditorMenuBar::copy, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMenuBar::*)()>(_a, &SieveEditorMenuBar::paste, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMenuBar::*)()>(_a, &SieveEditorMenuBar::cut, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMenuBar::*)()>(_a, &SieveEditorMenuBar::selectAll, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMenuBar::*)()>(_a, &SieveEditorMenuBar::comment, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMenuBar::*)()>(_a, &SieveEditorMenuBar::uncomment, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMenuBar::*)()>(_a, &SieveEditorMenuBar::zoomIn, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMenuBar::*)()>(_a, &SieveEditorMenuBar::zoomOut, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMenuBar::*)()>(_a, &SieveEditorMenuBar::debugSieveScript, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMenuBar::*)()>(_a, &SieveEditorMenuBar::zoomReset, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMenuBar::*)(bool )>(_a, &SieveEditorMenuBar::wordWrap, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMenuBar::*)()>(_a, &SieveEditorMenuBar::print, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMenuBar::*)()>(_a, &SieveEditorMenuBar::printPreview, 17))
            return;
    }
}

const QMetaObject *KSieveUi::SieveEditorMenuBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSieveUi::SieveEditorMenuBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KSieveUi18SieveEditorMenuBarE_t>.strings))
        return static_cast<void*>(this);
    return QMenuBar::qt_metacast(_clname);
}

int KSieveUi::SieveEditorMenuBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMenuBar::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void KSieveUi::SieveEditorMenuBar::gotoLine()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KSieveUi::SieveEditorMenuBar::find()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KSieveUi::SieveEditorMenuBar::replace()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KSieveUi::SieveEditorMenuBar::undo()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KSieveUi::SieveEditorMenuBar::redo()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KSieveUi::SieveEditorMenuBar::copy()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KSieveUi::SieveEditorMenuBar::paste()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KSieveUi::SieveEditorMenuBar::cut()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KSieveUi::SieveEditorMenuBar::selectAll()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KSieveUi::SieveEditorMenuBar::comment()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KSieveUi::SieveEditorMenuBar::uncomment()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KSieveUi::SieveEditorMenuBar::zoomIn()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void KSieveUi::SieveEditorMenuBar::zoomOut()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void KSieveUi::SieveEditorMenuBar::debugSieveScript()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void KSieveUi::SieveEditorMenuBar::zoomReset()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void KSieveUi::SieveEditorMenuBar::wordWrap(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void KSieveUi::SieveEditorMenuBar::print()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void KSieveUi::SieveEditorMenuBar::printPreview()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}
QT_WARNING_POP
