/****************************************************************************
** Meta object code from reading C++ file 'sieveeditorwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libksieve-26.08.0/src/ksieveui/editor/sieveeditorwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sieveeditorwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KSieveUi17SieveEditorWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto KSieveUi::SieveEditorWidget::qt_create_metaobjectdata<qt_meta_tag_ZN8KSieveUi17SieveEditorWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSieveUi::SieveEditorWidget",
        "checkSyntax",
        "",
        "enableButtonOk",
        "b",
        "valueChanged",
        "modeEditorChanged",
        "KSieveUi::SieveEditorWidget::EditorMode",
        "undoAvailable",
        "redoAvailable",
        "copyAvailable",
        "changeModeEditor",
        "sieveEditorTabCurrentChanged",
        "find",
        "replace",
        "undo",
        "redo",
        "paste",
        "copy",
        "cut",
        "selectAll",
        "goToLine",
        "slotSaveAs",
        "slotImport",
        "slotCreateRulesGraphically",
        "slotCheckSyntax",
        "comment",
        "uncomment",
        "setWordWrap",
        "state"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'checkSyntax'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableButtonOk'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'valueChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'modeEditorChanged'
        QtMocHelpers::SignalData<void(KSieveUi::SieveEditorWidget::EditorMode)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'undoAvailable'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'redoAvailable'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'copyAvailable'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'changeModeEditor'
        QtMocHelpers::SignalData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'sieveEditorTabCurrentChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'find'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'replace'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'undo'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'redo'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'paste'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copy'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cut'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectAll'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goToLine'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveAs'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotImport'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCreateRulesGraphically'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCheckSyntax'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'comment'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'uncomment'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setWordWrap'
        QtMocHelpers::SlotData<void(bool)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SieveEditorWidget, qt_meta_tag_ZN8KSieveUi17SieveEditorWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KSieveUi::SieveEditorWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KSieveUi17SieveEditorWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KSieveUi17SieveEditorWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KSieveUi17SieveEditorWidgetE_t>.metaTypes,
    nullptr
} };

void KSieveUi::SieveEditorWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SieveEditorWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->checkSyntax(); break;
        case 1: _t->enableButtonOk((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->valueChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->modeEditorChanged((*reinterpret_cast<std::add_pointer_t<KSieveUi::SieveEditorWidget::EditorMode>>(_a[1]))); break;
        case 4: _t->undoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->redoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->copyAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->changeModeEditor((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->sieveEditorTabCurrentChanged(); break;
        case 9: _t->find(); break;
        case 10: _t->replace(); break;
        case 11: _t->undo(); break;
        case 12: _t->redo(); break;
        case 13: _t->paste(); break;
        case 14: _t->copy(); break;
        case 15: _t->cut(); break;
        case 16: _t->selectAll(); break;
        case 17: _t->goToLine(); break;
        case 18: _t->slotSaveAs(); break;
        case 19: _t->slotImport(); break;
        case 20: _t->slotCreateRulesGraphically(); break;
        case 21: _t->slotCheckSyntax(); break;
        case 22: _t->comment(); break;
        case 23: _t->uncomment(); break;
        case 24: _t->setWordWrap((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SieveEditorWidget::*)()>(_a, &SieveEditorWidget::checkSyntax, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorWidget::*)(bool )>(_a, &SieveEditorWidget::enableButtonOk, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorWidget::*)(bool )>(_a, &SieveEditorWidget::valueChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorWidget::*)(KSieveUi::SieveEditorWidget::EditorMode )>(_a, &SieveEditorWidget::modeEditorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorWidget::*)(bool )>(_a, &SieveEditorWidget::undoAvailable, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorWidget::*)(bool )>(_a, &SieveEditorWidget::redoAvailable, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorWidget::*)(bool )>(_a, &SieveEditorWidget::copyAvailable, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorWidget::*)(bool )>(_a, &SieveEditorWidget::changeModeEditor, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorWidget::*)()>(_a, &SieveEditorWidget::sieveEditorTabCurrentChanged, 8))
            return;
    }
}

const QMetaObject *KSieveUi::SieveEditorWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSieveUi::SieveEditorWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KSieveUi17SieveEditorWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KSieveUi::SieveEditorWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void KSieveUi::SieveEditorWidget::checkSyntax()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KSieveUi::SieveEditorWidget::enableButtonOk(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KSieveUi::SieveEditorWidget::valueChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KSieveUi::SieveEditorWidget::modeEditorChanged(KSieveUi::SieveEditorWidget::EditorMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KSieveUi::SieveEditorWidget::undoAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KSieveUi::SieveEditorWidget::redoAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KSieveUi::SieveEditorWidget::copyAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KSieveUi::SieveEditorWidget::changeModeEditor(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void KSieveUi::SieveEditorWidget::sieveEditorTabCurrentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
