/****************************************************************************
** Meta object code from reading C++ file 'sessionthread_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libksieve-26.08.0/src/kmanagesieve/sessionthread_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sessionthread_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KManageSieve13SessionThreadE_t {};
} // unnamed namespace

template <> constexpr inline auto KManageSieve::SessionThread::qt_create_metaobjectdata<qt_meta_tag_ZN12KManageSieve13SessionThreadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KManageSieve::SessionThread",
        "responseReceived",
        "",
        "KManageSieve::Response",
        "response",
        "data",
        "error",
        "errorCode",
        "authenticationDone",
        "sslDone",
        "sslError",
        "KSslErrorUiData",
        "socketConnected",
        "socketDisconnected",
        "doInit",
        "doDestroy",
        "doConnectToHost",
        "QUrl",
        "url",
        "doDisconnectFromHost",
        "sendLogout",
        "doSendData",
        "doStartAuthentication",
        "doContinueAuthentication",
        "doStartSsl",
        "slotDataReceived",
        "slotSocketError",
        "slotSslTimeout",
        "slotEncryptedDone"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'responseReceived'
        QtMocHelpers::SignalData<void(const KManageSieve::Response &, const QByteArray &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QByteArray, 5 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(int, const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'authenticationDone'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sslDone'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sslError'
        QtMocHelpers::SignalData<void(const KSslErrorUiData &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 5 },
        }}),
        // Signal 'socketConnected'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'socketDisconnected'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'doInit'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'doDestroy'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'doConnectToHost'
        QtMocHelpers::SlotData<void(const QUrl &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'doDisconnectFromHost'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'doSendData'
        QtMocHelpers::SlotData<void(const QByteArray &)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QByteArray, 5 },
        }}),
        // Slot 'doStartAuthentication'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'doContinueAuthentication'
        QtMocHelpers::SlotData<void(const KManageSieve::Response &, const QByteArray &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QByteArray, 5 },
        }}),
        // Slot 'doStartSsl'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDataReceived'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSocketError'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSslTimeout'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEncryptedDone'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SessionThread, qt_meta_tag_ZN12KManageSieve13SessionThreadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KManageSieve::SessionThread::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KManageSieve13SessionThreadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KManageSieve13SessionThreadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KManageSieve13SessionThreadE_t>.metaTypes,
    nullptr
} };

void KManageSieve::SessionThread::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SessionThread *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->responseReceived((*reinterpret_cast<std::add_pointer_t<KManageSieve::Response>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 1: _t->error((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->authenticationDone(); break;
        case 3: _t->sslDone(); break;
        case 4: _t->sslError((*reinterpret_cast<std::add_pointer_t<KSslErrorUiData>>(_a[1]))); break;
        case 5: _t->socketConnected(); break;
        case 6: _t->socketDisconnected(); break;
        case 7: _t->doInit(); break;
        case 8: _t->doDestroy(); break;
        case 9: _t->doConnectToHost((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 10: _t->doDisconnectFromHost((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->doSendData((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 12: _t->doStartAuthentication(); break;
        case 13: _t->doContinueAuthentication((*reinterpret_cast<std::add_pointer_t<KManageSieve::Response>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 14: _t->doStartSsl(); break;
        case 15: _t->slotDataReceived(); break;
        case 16: _t->slotSocketError(); break;
        case 17: _t->slotSslTimeout(); break;
        case 18: _t->slotEncryptedDone(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SessionThread::*)(const KManageSieve::Response & , const QByteArray & )>(_a, &SessionThread::responseReceived, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionThread::*)(int , const QString & )>(_a, &SessionThread::error, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionThread::*)()>(_a, &SessionThread::authenticationDone, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionThread::*)()>(_a, &SessionThread::sslDone, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionThread::*)(const KSslErrorUiData & )>(_a, &SessionThread::sslError, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionThread::*)()>(_a, &SessionThread::socketConnected, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionThread::*)()>(_a, &SessionThread::socketDisconnected, 6))
            return;
    }
}

const QMetaObject *KManageSieve::SessionThread::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KManageSieve::SessionThread::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KManageSieve13SessionThreadE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KManageSieve::SessionThread::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void KManageSieve::SessionThread::responseReceived(const KManageSieve::Response & _t1, const QByteArray & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KManageSieve::SessionThread::error(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KManageSieve::SessionThread::authenticationDone()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KManageSieve::SessionThread::sslDone()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KManageSieve::SessionThread::sslError(const KSslErrorUiData & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KManageSieve::SessionThread::socketConnected()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KManageSieve::SessionThread::socketDisconnected()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
