// This file is generated by kconfig_compiler_kf6 from sieve-editor.kcfg.
// All changes you do to this file will be lost.
#ifndef KSIEVEUI_EDITORSETTINGS_H
#define KSIEVEUI_EDITORSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

namespace KSieveUi {

class EditorSettings : public KConfigSkeleton
{
  public:

    static EditorSettings *self();
    ~EditorSettings() override;

    /**
      Set Use graphical editor by default to edit sieve script.
    */
    static
    void setUseGraphicEditorByDefault( bool v )
    {
      if (!self()->isUseGraphicEditorByDefaultImmutable())
        self()->mUseGraphicEditorByDefault = v;
    }

    /**
      Get Use graphical editor by default to edit sieve script.
    */
    static
    bool useGraphicEditorByDefault()
    {
      return self()->mUseGraphicEditorByDefault;
    }

    /**
      Is Use graphical editor by default to edit sieve script. Immutable
    */
    static
    bool isUseGraphicEditorByDefaultImmutable()
    {
      return self()->isImmutable( QStringLiteral( "UseGraphicEditorByDefault" ) );
    }

    /**
      Get Item object corresponding to UseGraphicEditorByDefault()
    */
    ItemBool *useGraphicEditorByDefaultItem()
    {
      return mUseGraphicEditorByDefaultItem;
    }

  protected:
    EditorSettings();
    friend class EditorSettingsHelper;


    // General
    bool mUseGraphicEditorByDefault;

  private:
    ItemBool *mUseGraphicEditorByDefaultItem;
};

}

#endif

