/****************************************************************************
** Meta object code from reading C++ file 'vacationcreatescriptjob.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libksieve-26.08.0/src/ksievecore/vacation/vacationcreatescriptjob.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'vacationcreatescriptjob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10KSieveCore23VacationCreateScriptJobE_t {};
} // unnamed namespace

template <> constexpr inline auto KSieveCore::VacationCreateScriptJob::qt_create_metaobjectdata<qt_meta_tag_ZN10KSieveCore23VacationCreateScriptJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSieveCore::VacationCreateScriptJob",
        "result",
        "",
        "scriptActive",
        "activated",
        "serverName",
        "slotPutResult",
        "KManageSieve::SieveJob*",
        "job",
        "success",
        "slotGetScript",
        "oldScript",
        "active",
        "slotGotActiveScripts",
        "KSieveCore::ParseUserScriptJob*",
        "slotGenerateDone",
        "error"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'result'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'scriptActive'
        QtMocHelpers::SignalData<void(bool, const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'slotPutResult'
        QtMocHelpers::SlotData<void(KManageSieve::SieveJob *, bool)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Bool, 9 },
        }}),
        // Slot 'slotGetScript'
        QtMocHelpers::SlotData<void(KManageSieve::SieveJob *, bool, const QString &, bool)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Bool, 9 }, { QMetaType::QString, 11 }, { QMetaType::Bool, 12 },
        }}),
        // Slot 'slotGotActiveScripts'
        QtMocHelpers::SlotData<void(KSieveCore::ParseUserScriptJob *)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 8 },
        }}),
        // Slot 'slotGenerateDone'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'slotGenerateDone'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<VacationCreateScriptJob, qt_meta_tag_ZN10KSieveCore23VacationCreateScriptJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KSieveCore::VacationCreateScriptJob::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KSieveCore23VacationCreateScriptJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KSieveCore23VacationCreateScriptJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10KSieveCore23VacationCreateScriptJobE_t>.metaTypes,
    nullptr
} };

void KSieveCore::VacationCreateScriptJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VacationCreateScriptJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->result((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->scriptActive((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->slotPutResult((*reinterpret_cast<std::add_pointer_t<KManageSieve::SieveJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 3: _t->slotGetScript((*reinterpret_cast<std::add_pointer_t<KManageSieve::SieveJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 4: _t->slotGotActiveScripts((*reinterpret_cast<std::add_pointer_t<KSieveCore::ParseUserScriptJob*>>(_a[1]))); break;
        case 5: _t->slotGenerateDone((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->slotGenerateDone(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (VacationCreateScriptJob::*)(bool )>(_a, &VacationCreateScriptJob::result, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (VacationCreateScriptJob::*)(bool , const QString & )>(_a, &VacationCreateScriptJob::scriptActive, 1))
            return;
    }
}

const QMetaObject *KSieveCore::VacationCreateScriptJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSieveCore::VacationCreateScriptJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KSieveCore23VacationCreateScriptJobE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KSieveCore::VacationCreateScriptJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KSieveCore::VacationCreateScriptJob::result(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KSieveCore::VacationCreateScriptJob::scriptActive(bool _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
