/****************************************************************************
** Meta object code from reading C++ file 'sieveeditortextmodewidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libksieve-26.08.0/src/ksieveui/editor/sieveeditortextmodewidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sieveeditortextmodewidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KSieveUi25SieveEditorTextModeWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto KSieveUi::SieveEditorTextModeWidget::qt_create_metaobjectdata<qt_meta_tag_ZN8KSieveUi25SieveEditorTextModeWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSieveUi::SieveEditorTextModeWidget",
        "enableButtonOk",
        "",
        "switchToGraphicalMode",
        "valueChanged",
        "undoAvailable",
        "redoAvailable",
        "copyAvailable",
        "sieveEditorTabCurrentChanged",
        "slotShowGoToLine",
        "slotShareError",
        "message",
        "slotShareSuccess",
        "url"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enableButtonOk'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'switchToGraphicalMode'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'valueChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'undoAvailable'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'redoAvailable'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'copyAvailable'
        QtMocHelpers::SignalData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'sieveEditorTabCurrentChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowGoToLine'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShareError'
        QtMocHelpers::SlotData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'slotShareSuccess'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SieveEditorTextModeWidget, qt_meta_tag_ZN8KSieveUi25SieveEditorTextModeWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KSieveUi::SieveEditorTextModeWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<SieveEditorAbstractWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KSieveUi25SieveEditorTextModeWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KSieveUi25SieveEditorTextModeWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KSieveUi25SieveEditorTextModeWidgetE_t>.metaTypes,
    nullptr
} };

void KSieveUi::SieveEditorTextModeWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SieveEditorTextModeWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enableButtonOk((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->switchToGraphicalMode(); break;
        case 2: _t->valueChanged(); break;
        case 3: _t->undoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->redoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->copyAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->sieveEditorTabCurrentChanged(); break;
        case 7: _t->slotShowGoToLine(); break;
        case 8: _t->slotShareError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->slotShareSuccess((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SieveEditorTextModeWidget::*)(bool )>(_a, &SieveEditorTextModeWidget::enableButtonOk, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorTextModeWidget::*)()>(_a, &SieveEditorTextModeWidget::switchToGraphicalMode, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorTextModeWidget::*)()>(_a, &SieveEditorTextModeWidget::valueChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorTextModeWidget::*)(bool )>(_a, &SieveEditorTextModeWidget::undoAvailable, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorTextModeWidget::*)(bool )>(_a, &SieveEditorTextModeWidget::redoAvailable, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorTextModeWidget::*)(bool )>(_a, &SieveEditorTextModeWidget::copyAvailable, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorTextModeWidget::*)()>(_a, &SieveEditorTextModeWidget::sieveEditorTabCurrentChanged, 6))
            return;
    }
}

const QMetaObject *KSieveUi::SieveEditorTextModeWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSieveUi::SieveEditorTextModeWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KSieveUi25SieveEditorTextModeWidgetE_t>.strings))
        return static_cast<void*>(this);
    return SieveEditorAbstractWidget::qt_metacast(_clname);
}

int KSieveUi::SieveEditorTextModeWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SieveEditorAbstractWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void KSieveUi::SieveEditorTextModeWidget::enableButtonOk(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KSieveUi::SieveEditorTextModeWidget::switchToGraphicalMode()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KSieveUi::SieveEditorTextModeWidget::valueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KSieveUi::SieveEditorTextModeWidget::undoAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KSieveUi::SieveEditorTextModeWidget::redoAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KSieveUi::SieveEditorTextModeWidget::copyAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KSieveUi::SieveEditorTextModeWidget::sieveEditorTabCurrentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
