/****************************************************************************
** Meta object code from reading C++ file 'sieveeditorhelphtmlwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libksieve-26.08.0/src/ksieveui/editor/webengine/sieveeditorhelphtmlwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sieveeditorhelphtmlwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KSieveUi25SieveEditorHelpHtmlWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto KSieveUi::SieveEditorHelpHtmlWidget::qt_create_metaobjectdata<qt_meta_tag_ZN8KSieveUi25SieveEditorHelpHtmlWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSieveUi::SieveEditorHelpHtmlWidget",
        "titleChanged",
        "",
        "KSieveUi::SieveEditorHelpHtmlWidget*",
        "widget",
        "title",
        "progressIndicatorPixmapChanged",
        "QPixmap",
        "loadFinished",
        "success",
        "copyAvailable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void(KSieveUi::SieveEditorHelpHtmlWidget *, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'progressIndicatorPixmapChanged'
        QtMocHelpers::SignalData<void(KSieveUi::SieveEditorHelpHtmlWidget *, const QPixmap &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 7, 2 },
        }}),
        // Signal 'loadFinished'
        QtMocHelpers::SignalData<void(KSieveUi::SieveEditorHelpHtmlWidget *, bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 9 },
        }}),
        // Signal 'copyAvailable'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SieveEditorHelpHtmlWidget, qt_meta_tag_ZN8KSieveUi25SieveEditorHelpHtmlWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KSieveUi::SieveEditorHelpHtmlWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KSieveUi25SieveEditorHelpHtmlWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KSieveUi25SieveEditorHelpHtmlWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KSieveUi25SieveEditorHelpHtmlWidgetE_t>.metaTypes,
    nullptr
} };

void KSieveUi::SieveEditorHelpHtmlWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SieveEditorHelpHtmlWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->titleChanged((*reinterpret_cast<std::add_pointer_t<KSieveUi::SieveEditorHelpHtmlWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->progressIndicatorPixmapChanged((*reinterpret_cast<std::add_pointer_t<KSieveUi::SieveEditorHelpHtmlWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[2]))); break;
        case 2: _t->loadFinished((*reinterpret_cast<std::add_pointer_t<KSieveUi::SieveEditorHelpHtmlWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 3: _t->copyAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KSieveUi::SieveEditorHelpHtmlWidget* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KSieveUi::SieveEditorHelpHtmlWidget* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KSieveUi::SieveEditorHelpHtmlWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SieveEditorHelpHtmlWidget::*)(KSieveUi::SieveEditorHelpHtmlWidget * , const QString & )>(_a, &SieveEditorHelpHtmlWidget::titleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorHelpHtmlWidget::*)(KSieveUi::SieveEditorHelpHtmlWidget * , const QPixmap & )>(_a, &SieveEditorHelpHtmlWidget::progressIndicatorPixmapChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorHelpHtmlWidget::*)(KSieveUi::SieveEditorHelpHtmlWidget * , bool )>(_a, &SieveEditorHelpHtmlWidget::loadFinished, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorHelpHtmlWidget::*)(bool )>(_a, &SieveEditorHelpHtmlWidget::copyAvailable, 3))
            return;
    }
}

const QMetaObject *KSieveUi::SieveEditorHelpHtmlWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSieveUi::SieveEditorHelpHtmlWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KSieveUi25SieveEditorHelpHtmlWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KSieveUi::SieveEditorHelpHtmlWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KSieveUi::SieveEditorHelpHtmlWidget::titleChanged(KSieveUi::SieveEditorHelpHtmlWidget * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KSieveUi::SieveEditorHelpHtmlWidget::progressIndicatorPixmapChanged(KSieveUi::SieveEditorHelpHtmlWidget * _t1, const QPixmap & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KSieveUi::SieveEditorHelpHtmlWidget::loadFinished(KSieveUi::SieveEditorHelpHtmlWidget * _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KSieveUi::SieveEditorHelpHtmlWidget::copyAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
