/****************************************************************************
** Meta object code from reading C++ file 'sievedebugdialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libksieve-26.08.0/src/ksieveui/debug/sievedebugdialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sievedebugdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KSieveUi16SieveDebugDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto KSieveUi::SieveDebugDialog::qt_create_metaobjectdata<qt_meta_tag_ZN8KSieveUi16SieveDebugDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSieveUi::SieveDebugDialog",
        "slotGetScript",
        "",
        "KManageSieve::SieveJob*",
        "job",
        "success",
        "script",
        "active",
        "slotGetScriptList",
        "scriptList",
        "activeScript",
        "slotDiagNextAccount",
        "slotDiagNextScript",
        "slotShutDownJob"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotGetScript'
        QtMocHelpers::SlotData<void(KManageSieve::SieveJob *, bool, const QString &, bool)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 }, { QMetaType::QString, 6 }, { QMetaType::Bool, 7 },
        }}),
        // Slot 'slotGetScriptList'
        QtMocHelpers::SlotData<void(KManageSieve::SieveJob *, bool, const QStringList &, const QString &)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 }, { QMetaType::QStringList, 9 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'slotDiagNextAccount'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDiagNextScript'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShutDownJob'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SieveDebugDialog, qt_meta_tag_ZN8KSieveUi16SieveDebugDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KSieveUi::SieveDebugDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KSieveUi16SieveDebugDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KSieveUi16SieveDebugDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KSieveUi16SieveDebugDialogE_t>.metaTypes,
    nullptr
} };

void KSieveUi::SieveDebugDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SieveDebugDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotGetScript((*reinterpret_cast<std::add_pointer_t<KManageSieve::SieveJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 1: _t->slotGetScriptList((*reinterpret_cast<std::add_pointer_t<KManageSieve::SieveJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 2: _t->slotDiagNextAccount(); break;
        case 3: _t->slotDiagNextScript(); break;
        case 4: _t->slotShutDownJob(); break;
        default: ;
        }
    }
}

const QMetaObject *KSieveUi::SieveDebugDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSieveUi::SieveDebugDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KSieveUi16SieveDebugDialogE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int KSieveUi::SieveDebugDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
